summaryrefslogtreecommitdiffstats
path: root/ui/message_center/notification_list.h
diff options
context:
space:
mode:
authormukai@chromium.org <mukai@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-04-17 21:51:46 +0000
committermukai@chromium.org <mukai@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-04-17 21:51:46 +0000
commitbf9b054c1892e05d06dcdf123d86862a09b86db0 (patch)
tree83580ea805739c1ef307f094315bc0033a579608 /ui/message_center/notification_list.h
parentd660fa8b7137cb8c1100d7dd3958c9c6ef10cf2b (diff)
downloadchromium_src-bf9b054c1892e05d06dcdf123d86862a09b86db0.zip
chromium_src-bf9b054c1892e05d06dcdf123d86862a09b86db0.tar.gz
chromium_src-bf9b054c1892e05d06dcdf123d86862a09b86db0.tar.bz2
Sends Updated when message center is closed.
Because open/close will change the notification status (read/shown), it should send Updated to the observers. BUG=232030 TEST=manually (see repro steps in the bug) R=dewittj@chromium.org Review URL: https://codereview.chromium.org/14299007 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@194698 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ui/message_center/notification_list.h')
-rw-r--r--ui/message_center/notification_list.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/ui/message_center/notification_list.h b/ui/message_center/notification_list.h
index 852107d..f69b188 100644
--- a/ui/message_center/notification_list.h
+++ b/ui/message_center/notification_list.h
@@ -49,8 +49,11 @@ class MESSAGE_CENTER_EXPORT NotificationList {
explicit NotificationList();
virtual ~NotificationList();
- // Affects whether or not a message has been "read".
- void SetMessageCenterVisible(bool visible);
+ // Affects whether or not a message has been "read". Collects the set of
+ // ids whose state have changed and set to |udpated_ids|. NULL if updated
+ // ids don't matter.
+ void SetMessageCenterVisible(bool visible,
+ std::set<std::string>* updated_ids);
void AddNotification(NotificationType type,
const std::string& id,